#include "wifi_check.h"
#include "wifi.h"
#include "ets_sys.h"
#include "osapi.h"
#include "driver\i2s.h"
#include "user_interface.h"
#include <os_type.h>
#include <espconn.h>


extern int ets_uart_printf(const char *fmt, ...);
int (*console_printf)(const char *fmt, ...) = ets_uart_printf;


LOCAL void ICACHE_FLASH_ATTR show_info(void) {
    ets_uart_printf("\n[System info]\n");
    ets_uart_printf("SDK version: %s\n", system_get_sdk_version());
    ets_uart_printf("Time = %ld\n", system_get_time());
    ets_uart_printf("Chip id = 0x%x\n", system_get_chip_id());
    ets_uart_printf("Free heap size = %d\n", system_get_free_heap_size());
    ets_uart_printf("PHY mode = %08X\n", wifi_get_phy_mode());
    ets_uart_printf("==========================================\n");
}

/******************************************************************************
 * FunctionName : user_rf_cal_sector_set
 * Description  : SDK just reversed 4 sectors, used for rf init data and paramters.
 *                We add this function to force users to set rf cal sector, since
 *                we don't know which sector is free in user's application.
 *                sector map for last several sectors : ABBBCDDD
 *                A : rf cal
 *                B : at parameters
 *                C : rf init data
 *                D : sdk parameters
 * Parameters   : none
 * Returns      : rf cal sector
*******************************************************************************/
uint32 ICACHE_FLASH_ATTR user_rf_cal_sector_set(void)
{
    enum flash_size_map size_map = system_get_flash_size_map();
    uint32 rf_cal_sec = 0;

    switch (size_map) {
        case FLASH_SIZE_4M_MAP_256_256:
            rf_cal_sec = 128 - 8;
            break;

        case FLASH_SIZE_8M_MAP_512_512:
            rf_cal_sec = 256 - 5;
            break;

        case FLASH_SIZE_16M_MAP_512_512:
        case FLASH_SIZE_16M_MAP_1024_1024:
            rf_cal_sec = 512 - 5;
            break;

        case FLASH_SIZE_32M_MAP_512_512:
        case FLASH_SIZE_32M_MAP_1024_1024:
            rf_cal_sec = 1024 - 5;
            break;

        default:
            rf_cal_sec = 0;
            break;
    }

    return rf_cal_sec;
}


void user_rf_pre_init(void)
{
}

void user_init(void) {
    //system_update_cpu_freq(160);

    // Configure the UART
    uart_init(230400, 230400);
    os_delay_us(1000);

    // Enable system messages
    system_set_os_print(1);
    os_printf("\nSystem init...\n");
    show_info();

    if (wifi_get_phy_mode() != PHY_MODE_11G) {
        os_printf("Changing PHY mode to 802.11g\n");
        wifi_set_phy_mode(PHY_MODE_11G);
    }
#if 0
    //if(wifi_get_opmode() != STATION_MODE) {
    //    os_printf("ESP8266 is %s mode, restarting in %s mode...\n", WiFiMode[wifi_get_opmode()], WiFiMode[STATION_MODE]);
        setup_wifi_st_mode();
    //}
#else
    if (wifi_get_opmode() != SOFTAP_MODE) {
        os_printf("ESP8266 is %s mode, restarting in %s mode...\n", WiFiMode[wifi_get_opmode()], WiFiMode[SOFTAP_MODE]);
        setup_wifi_ap_mode();
    }
#endif

    wifi_check_init();

    rtp_rx_init();

    i2s_run();
}

